==> sems-0.8.12.tar.gz: sems-0.8.12/plug-in/isdngw/IsdnCallManager.h <==
/*
 * $Id: IsdnCallManager.h,v 1.1.2.1 2004/01/23 13:40:58 ullstar Exp $
 *
 * Copyright (C) 2003 Ulrich Abend
 *
 * This file is part of isdngw, a free isdn gateway plugin 
 * for sems, a free SIP media server.
 *
 * isdngw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * isdngw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef _ISDNCALLMANAGER_H_
#define _ISDNCALLMANAGER_H_

#include <pthread.h>
#include "globals.h"

#include "IsdnCall.h"



class IsdnCallManager
{
public:
	~IsdnCallManager();
	static void instantiate();

	void init();

	/* backend is CONNECTIONTYPE_CAPI or CONNECTIONTYPE_i4l, ref is 
	   pointer to CapiConnection or IsdnDevice object */
	IsdnCall* placeCallFromPSTN(char* fromnumber, char* tonumber, int backend, void* ref);

	/* this can be a call from PSTN, key matching to determine this is inside this func */
	IsdnCall* placeCallFromSIP(AmCmd cmd);

	/* a call is finished, remove all references and store CDR */
	void callDone(IsdnCall* call);

	/* something happend that should be remembered in history */
	void updateCall(IsdnCall* call, CallDetail* callDetail, char* prefix = "");
	
	/* dump all current connections and their state */
	void dumpDetailsOfCalls();
	void dumpDetails(CallDetail* calldetails);

	IsdnCall* changeSIPState(AmCmd cmd, int newstate);

	CallDetail* addCall(IsdnCall* call);
	void diedCall(IsdnCall* call, CallDetail* calldetail);
	void update(IsdnCall* call, CallDetail* calldetail);

	private:
	/* private, because only one global instance needed, used instantiate once */
	IsdnCallManager();
	CallDetail* m_callDetails;
};

extern IsdnCallManager* callManager;
#endif

==> sems-0.9.0.tar.gz: sems-0.9.0/plug-in/isdngw/IsdnCallManager.h <==
/*
 * $Id: IsdnCallManager.h,v 1.5 2004/08/13 13:50:38 rco Exp $
 *
 * Copyright (C) 2003 Ulrich Abend
 *
 * This file is part of isdngw, a free isdn gateway plugin 
 * for sems, a free SIP media server.
 *
 * isdngw is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version
 *
 * For a license to use the ser software under conditions
 * other than those described here, or to purchase support for this
 * software, please contact iptel.org by e-mail at the following addresses:
 *    info@iptel.org
 *
 * isdngw is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this program; if not, write to the Free Software 
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


#ifndef _ISDNCALLMANAGER_H_
#define _ISDNCALLMANAGER_H_

#include <pthread.h>
#include "AmServer.h"

#include "globals.h"
#include "IsdnCall.h"



class IsdnCallManager: public AmFifoServerFct
{
public:
	~IsdnCallManager();
	static void instantiate();

	void init();

	/* backend is CONNECTIONTYPE_CAPI or CONNECTIONTYPE_i4l, ref is 
	   pointer to CapiConnection or IsdnDevice object */
	IsdnCall* placeCallFromPSTN(char* fromnumber, char* tonumber, int backend, void* ref);

	/* this can be a call from PSTN, key matching to determine this is inside this func */
	IsdnCall* placeCallFromSIP(AmCmd cmd);

	/* a call is finished, remove all references and store CDR */
	void callDone(IsdnCall* call);

	/* something happend that should be remembered in history */
	void updateCall(IsdnCall* call, CallDetail* callDetail, char* prefix = "");
	void updateCallParameters(IsdnCall* call, CallDetail* callDetail);
	
	/* dump all current connections and their state */
	void dumpDetailsOfCalls();
	void dumpDetails(CallDetail* calldetails);

	IsdnCall* changeSIPState(AmCmd cmd, int newstate);

	CallDetail* addCall(IsdnCall* call);
	void diedCall(IsdnCall* call, CallDetail* calldetail);
	void update(IsdnCall* call, CallDetail* calldetail);

	int execute(FILE* file, const string& s);

	private:
	/* private, because only one global instance needed, used instantiate once */
	IsdnCallManager();
	CallDetail* m_callDetails;

	pthread_mutex_t details_m;
	int m_idcounter;
	int getNewId();

	CallDetail* getDetailsForId(int id);
	int deleteDetails(CallDetail*);

	#define FIFO_COMMAND_LISTCALLS "listcalls"
	void fifo_listcalls(FILE* reply);
	#define FIFO_COMMAND_CALLDETAILS "calldetails"
	void fifo_calldetails(FILE* reply, char* parameter);
	#define FIFO_COMMAND_DELETEDETAILS "deletedetails"
	void fifo_deletedetails(FILE* reply, char* parameter);
	#define FIFO_COMMAND_DUMPDEVICES "dumpdevices"
	void fifo_dumpdevices(FILE* reply);
};

extern IsdnCallManager* callManager;
#endif
